
###########################################################################
## Sæt working directory

## I RStudio kan man nemt sætte working directory med menuen 
## "Session -> Set Working Directory -> To Source File Location" 
## Bemærk: i R bruges kun "/" til separering i stier 
## (altså ingen backslash).
setwd("Erstat her med stien til den mappe, hvor projektfilerne er gemt.")


###########################################################################
## Indlæs data

## Indlæs data fra skivefjord1_data.csv
D <- read.table("skivefjord1_data.csv", header=TRUE, sep=";", 
                as.is=TRUE)


###########################################################################
## Simpel opsummering af data

## Dimensionen af D (antallet af rækker og søjler)
dim(D)
## Søjle-/variabelnavne
names(D)
## De første rækker/observationer
head(D)
## De sidste rækker/observationer
tail(D)
## Udvalgte opsummerende størrelser
summary(D)
## En anden type opsummering af datasættet
str(D)


###########################################################################
## Histogram (empirisk tæthed)

## Histogram der beskriver den empiriske tæthed for de 
## årlige målinger af nitratudledningen (histogram for 
## de årlige målinger normaliseret så arealet er lig 1)
hist(D$Nload, xlab="Nitratudledning", prob=TRUE)


###########################################################################
## Opdeling af data i delmængder

## Delmængde for VMP0 (dvs. før første VMP)
VMP0 <- subset(D, vmp == 0)
## Check at det er en data.frame med alle værdier fra VMP 0
VMP0
## En delmængde for VMP1
VMP1 <- subset(D, vmp == 1)
## En delmængde for VMP2
VMP2 <- subset(D, vmp == 2)
## En delmængde for VMP3
VMP3 <- subset(D, vmp == 3)


###########################################################################
## Plot af udvikling over tid

## Plot af nitratudledning over tid (farvet efter gældende VMP)
plot(D$year, D$Nload, type="b", xlab="År", ylab="Nitratudledning")
lines(VMP0$year, VMP0$Nload, type="b", col=2)
lines(VMP1$year, VMP1$Nload, type="b", col=3)
lines(VMP2$year, VMP2$Nload, type="b", col=4)
lines(VMP3$year, VMP3$Nload, type="b", col=5)
## Tilføj en legend
legend("topright", paste0("VMP", 0:3), lty=1, col=2:5)


###########################################################################
## Boxplot opdelt efter VMP

## Boxplot af nitratudledning opdelt efter VMP
boxplot(VMP0$Nload, VMP1$Nload, VMP2$Nload, VMP3$Nload, 
        names=c("VMP0", "VMP1", "VMP2", "VMP3"), 
        xlab="VMP", ylab="Nitratudledning")


###########################################################################
## Opsummerende størrelser for nitratudledningen

## Antal observationer af nitratudledningen under VMP0
## (medregner ej eventuelle manglende værdier)
sum(!is.na(VMP0$Nload))
## Stikprøvegennemsnit for nitratudledningen under VMP0
mean(VMP0$Nload, na.rm=TRUE)
## Stikprøvevarians for nitratudledningen under VMP0
var(VMP0$Nload, na.rm=TRUE)
## osv.
## Argumentet 'na.rm=TRUE' sørger for at størrelsen
## udregnes selvom der eventuelt er manglende værdier


###########################################################################
## qq-plot til modelkontrol

## qq-plot for nitratudledning under VMP0
qqnorm(VMP0$Nload)
qqline(VMP0$Nload)


###########################################################################
## Konfidensinterval for middelværdi

## Konfidensinterval for middelværdi af årlig nitratudledning under VMP0
t.test(VMP0$Nload, conf.level=0.95)$conf.int


###########################################################################
## T-test for en enkelt stikprøve

## Test af hypotesen mu=2000 for årlig nitratudledning under VMP0
t.test(VMP0$Nload, mu=2000)


###########################################################################
## Welch t-test for sammenligning af to (uafhængige) stikprøver

## Sammenligning af årlig nitratudledning under VMP0 og VMP3
t.test(VMP0$Nload, VMP3$Nload)


###########################################################################
## Beregning af korrelation

## Beregning af korrelation mellem Nload og Pload
cor(D[, c("Nload","Pload")], use="pairwise.complete.obs")

  
###########################################################################
## Delmængder i R

## Ekstra bemærkning om måder at udtage delmænger i R
##
## En logisk (logical) vektor med sandt (TRUE) eller falsk (FALSE) 
## som for hver række i D undersøger om observationen er fra VMP0
D$vmp == 0
## Vektoren kan bruges til at udvælge alle observationer fra VMP0
D[D$vmp == 0, ]
## En vektor af denne type kunne også bruges til at plotte data
## fra hver VMP i en for-løkke
plot(D$year, D$Nload, type="n")
for(i in 0:3){
  lines(D$year[D$vmp == i], D$Nload[D$vmp == i], type="b", col=i+2)
}
## Mere komplekse logiske udtryk kan laves, f.eks.:
## Find alle observationer fra efter 1984 og fra VMP 0
D[D$year > 1984 & D$vmp == 0, ]


###########################################################################
## Flere R-tips

## Lav en for-løkke med beregning af et par opsummerende størrelser
## og gem resultatet i en ny data.frame
Tbl <- data.frame()
for(i in 0:3){
  Tbl[i+1,"mean"] <- mean(D$Nload[D$vmp == i])
  Tbl[i+1,"var"] <- var(D$Nload[D$vmp == i])
}
## Se hvad der er i Tbl
Tbl

## I R er der endnu mere kortfattede måder sådanne udregninger kan 
## udføres. For eksempel
aggregate(D$Nload, by=list(D$vmp), function(x){ c(mean(x), var(x)) })
## Se flere smarte funktioner med: ?apply, ?aggregate og ?lapply
## og for ekstremt effektiv databehandling se f.eks. pakkerne: dplyr,
## tidyr, reshape2 og ggplot2.

## LaTeX tips:
##
## R-pakken "xtable" kan generere LaTeX tabeller og skrive dem direkte 
## ind i en fil, som derefter kan inkluderes i et .tex dokument.
## 
## R-pakken "knitr" kan anvendes meget elegant til at lave et .tex 
## dokument der inkluderer R koden direkte i dokumentet. Dette
## dokument og bogen er lavet med knitr.
